@@ -15,10 +15,8 @@ int main()
 
   /* Note: The third argument of the following function may also be a
      valid IP address in the form of a string. i.e. 192.168.0.1 */
-  MC_SendAgentMigrationMessage(agency,
-      str,
-      "localhost",
-      5051);
+  MC_SendAgent(agency,
+      str);
   MC_End(agency);
   exit(0);
 }
