@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 443 $ : Last Committed Revision
- * $Date: 2010-03-07 15:48:49 -0800 (Sun, 07 Mar 2010) $ : Last Committed Date */
+ * $Revision: 519 $ : Last Committed Revision
+ * $Date: 2010-06-11 14:26:03 -0700 (Fri, 11 Jun 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -34,13 +34,23 @@
 
 #ifndef _AGENT_LIB_H_
 #define _AGENT_LIB_H_
+EXPORTCH int MC_AclGetProtocol_chdl(void* varg);
+
+EXPORTCH char* MC_AclGetConversationID_chdl(void *varg);
+
+EXPORTCH int MC_AclGetPerformative_chdl(void *varg);
+
+EXPORTCH int MC_AclGetSender_chdl(void *varg);
+  
+EXPORTCH char* MC_AclGetContent_chdl(void *varg);
+
 EXPORTCH int
 MC_AclDestroy_chdl(void* varg);
 
 EXPORTCH void* 
 MC_AclNew_chdl(void* varg);
 
-EXPORTCH void*
+EXPORTCH int
 MC_AclPost_chdl(void* varg);
 
 EXPORTCH void*
@@ -57,31 +67,34 @@ MC_AclWaitRetrieve_chdl(void *varg);
 
 /* BEGIN Acl helper functions */
 
-EXPORTCH void*
+EXPORTCH int
 MC_AclSetProtocol_chdl(void *varg);
 
-EXPORTCH void*
+EXPORTCH int
 MC_AclSetConversationID_chdl(void *varg);
 
-EXPORTCH void*
+EXPORTCH int
 MC_AclSetPerformative_chdl(void *varg);
 
-EXPORTCH void*
+EXPORTCH int
 MC_AclSetSender_chdl(void *varg);
 
-EXPORTCH void*
+EXPORTCH int
 MC_AclAddReceiver_chdl(void *varg);
 
-EXPORTCH void*
+EXPORTCH int
 MC_AclAddReplyTo_chdl(void *varg);
 
-EXPORTCH void*
+EXPORTCH int
 MC_AclSetContent_chdl(void *varg);
 /* END Acl helper functions */
 
 EXPORTCH int
 MC_AddAgent_chdl(void *varg);
 
+EXPORTCH int
+MC_AgentAddTask_chdl(void *varg);
+
 EXPORTCH const void*
 MC_AgentVariableRetrieve_chdl(void* varg);
 
@@ -100,11 +113,17 @@ MC_BarrierInit_chdl(void *varg);
 EXPORTCH int
 MC_CallAgentFunc_chdl(void *varg);
 
-EXPORTCH int
+EXPORTCH MCAgent_t
 MC_ComposeAgent_chdl(void *varg);
 
-EXPORTCH int
-MC_ComposeAgentS_chdl(void *varg);
+EXPORTCH MCAgent_t
+MC_ComposeAgentWithWorkgroup_chdl(void *varg);
+
+EXPORTCH MCAgent_t 
+MC_ComposeAgentFromFile_chdl(void *varg);
+
+EXPORTCH MCAgent_t 
+MC_ComposeAgentFromFileWithWorkgroup_chdl(void *varg);
 
 EXPORTCH int
 MC_CondBroadcast_chdl(void *varg);
@@ -193,7 +212,7 @@ MC_RetrieveAgent_chdl(void *varg);
 EXPORTCH char *
 MC_RetrieveAgentCode_chdl(void *varg);
 
-EXPORTCH char *
+EXPORTCH int
 MC_SearchForService_chdl(void *varg);
 
 EXPORTCH int
