@@ -1,6 +1,6 @@
 /* SVN FILE INFO
- * $Revision: 402 $ : Last Committed Revision
- * $Date: 2009-08-23 13:44:39 -0700 (Sun, 23 Aug 2009) $ : Last Committed Date */
+ * $Revision: 517 $ : Last Committed Revision
+ * $Date: 2010-06-11 12:06:47 -0700 (Fri, 11 Jun 2010) $ : Last Committed Date */
 /*[
  * Copyright (c) 2007 Integration Engineering Laboratory
                       University of California, Davis
@@ -39,8 +39,8 @@
 #include "agent.h"
 
 STRUCT ( xml_parser,
-    const mxml_node_t *root;
-    const mxml_node_t *node; );
+    mxml_node_t *root;
+    mxml_node_t *node; );
 
 
 error_code_t 
